#
# spec file for package python-reproject
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-reproject%{psuffix}
Version:        0.14.1
Release:        1.2
Summary:        Reproject astronomical images
License:        BSD-3-Clause
URL:            https://reproject.readthedocs.io
# Repo-URL:     https://github.com/astropy/reproject
Source:         https://github.com/astropy/reproject/archive/refs/tags/v%{version}.tar.gz#/reproject-%{version}-gh.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module extension-helpers}
BuildRequires:  %{python_module numpy-devel >= 1.17}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-astropy >= 5
Requires:       python-astropy-healpix >= 1
Requires:       python-cloudpickle
Requires:       python-dask-array >= 2021.8
Requires:       python-fsspec
Requires:       python-numpy >= 1.23
Requires:       python-scipy >= 1.9
Requires:       python-zarr
%if %{with test}
BuildRequires:  %{python_module Shapely >= 2.0.2}
BuildRequires:  %{python_module asdf}
BuildRequires:  %{python_module gwcs}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pytest-arraydiff >= 0.5}
BuildRequires:  %{python_module pytest-astropy}
BuildRequires:  %{python_module pytest-doctestplus}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyvo}
BuildRequires:  %{python_module reproject = %{version}}
%endif
%python_subpackages

%description
Reproject astronomical images

%prep
%setup -q -n reproject-%{version}

%build
%if !%{with test}
export CFLAGS="%{optflags}"
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%{python_expand #
rm -r %{buildroot}%{$python_sitearch}/reproject/spherical_intersect/*.h
%fdupes %{buildroot}%{$python_sitearch}
}
%endif

%if %{with test}
%check
mv reproject reproject.src
# cannot edit FITS file in system
donttest='test_reproject_order[block_size1]'
%pytest_arch -n auto --pyargs reproject -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGES.md README.rst
%license LICENSE
%{python_sitearch}/reproject
%{python_sitearch}/reproject-%{version}.dist-info
%endif

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * Enforce readonly mode for memmap when reading input array
  * Fix Continuous Integration folllowing changes in Sunpy 6.0.0
    and 6.0.1
  * MNT: Use hash for Action workflow versions and update if
    needed
* Mon Sep  2 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  [#]# Bug Fixes
  * Support readonly arrays in adaptive by @svank in #452
  * Fix bug with artifacts in reproject_to_healpix by @astrofrog in
    [#459]
  [#]# New Features
  * Fix multi-threaded reprojection when using Astropy WCS by
    @astrofrog in #434
  * Generalize reproject_and_coadd for N-dimensional data, and add
    option to specify blank pixel value and progress bar by
    @keflavich in #351
  * Improve performance for large datasets and switch to
    multi-threading by default by @astrofrog in #443
  [#]# Other Changes
  * Don't use --pre on Python 3.12 by @astrofrog in #445
  * Bump minimum required version of astropy-healpix by @astrofrog
    in #446
  * Improvements to performance when using dask.distributed by
    @astrofrog in #447
  * Add logging calls and fix a couple of dask-related issues by
    @astrofrog in #450
  * Add a script to regenerate the aia asdf file and do so by
    @Cadair in #439
  * Performance improvements for interpolation with map_coordinates
    by @astrofrog in #448
- Release v0.13.1
  [#]# Bug Fixes
  * Ensure reproject_and_coadd handles bg-matching with one input
    image by @svank in #412
  * Fixes for mosaic output pixels not covered by inputs by @svank
    in #413
  [#]# Documentation
  * Updated docstrings for output_projection and shape_out to
    indicate that any APE-14 WCS is acceptable by @astrofrog in
    [#407]
  [#]# Other Changes
  * Add tests for full range of inputs/outputs in healpix functions
    by @astrofrog in #408
  * Fix Cython warnings by @svank in #418
  * Build against Numpy 2.0.0rc1 or later by @astrofrog in #436
- Release v0.13.0
  [#]# Bug Fixes
  * Fix TestReprojectAndCoAdd failure on i386 by @olebole in #386
  * Fixed a bug that caused reprojected dask arrays to not be
    computable due to a temporary directory being removed by
    @astrofrog in #390
  [#]# New Features
  * Add ability to specify output array and footprint in
    reproject_and_coadd by @astrofrog in #387
  * Added ability to set block_size='auto' and fix missing
    parameters in docstrings by @astrofrog in #392
  * Compute footprint in healpix_to_image by @lpsinger in #400
  [#]# Other Changes
  * Fix compatibility with Cython 3.0.2 and update version in
    pyproject.toml by @astrofrog in #391
- Release 0.12.0
  [#]# Bug Fixes
  * Fix support for NDData objects with dask .data attributes by
    @astrofrog in #365
  * Fix docs mosaic page rendering by @jdavies-st in #381
  [#]# New Features
  * Add despike_jacobian option for adaptive resampling by @svank
    in #366
  * Refactor blocked/parallel reprojection by @astrofrog in #374
  * Add 'first' and 'last' moasicking modes to reproject_and_coadd
    by @svank in #383
  * Add modes for nan and inf handling to adaptive algo by @svank
    in #380
  * Added new combine function to compute the minimum and maximum
    by @fjankowsk in #369
  [#]# Other Changes
  * Dask support improvements by @astrofrog in #367
  * Fix --remote-data tests by @astrofrog in #375
  * Update docstring for adaptive defaults by @svank in #378
  * Use more points to find image bounds in moasics by @svank in
    [#382]
- Release v0.11.0
  [#]# Bug Fixes
  * Fix for HighLevelWCS attribute error by @keflavich in #349
  * Fixes for solar frames and non-degree units by @astrofrog in
    [#360]
  * If shape_out is specified, use this over the array_shape
    attribute of a WCS object by @astrofrog in #361
  [#]# New Features
  * Allow single inputs to find_optimal_celestial_wcs and add
    ability to specify HDU by @astrofrog in #344
  * Add support for specifying output projection as APE 14 WCS with
    array_shape defined by @astrofrog in #345
  * Started adding support for allowing dask arrays as input by
    @astrofrog in #352
  [#]# Other Changes
  * Mark tests that use remote data by @smaret in #339
  * Simplify blocked reprojection implementation by using dask and
    improve efficiency of parallel reprojection by @astrofrog in
    [#314]
  * Remove code that was required for astropy<4 by @astrofrog in
    [#346]
  * Add a new 'all' extras for shapely by @astrofrog in #363
- Release v0.10.0
  [#]# Bugs Fixed
  * Close FITS files after loading by @svank in #330
  [#]# New Features
  * Add support for blocked and parallel reprojection in
    reproject_interp by @AlistairSymonds in #214
  * Add support for efficiently reprojecting multiple images with
    the same wcs by @svank in #332
  * Add support for APE 14 WCSes in find_optimal_celestial_wcs by
    @astrofrog in #334
  [#]# Other Changes
  * Changed default filter kernel and boundary mode in
    reproject_adaptive, and removed order argument. by @svank in
    [#291]
  * Use pixel_to_pixel from astropy.wcs.utils by @astrofrog in #315
  * Speed up test_blocked_against_single by increasing smallest
    block size by @astrofrog in #319
* Mon Nov  7 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.9.1
  * support for Python 3.11
- Release v0.9
  * Drop support for Python 3.7.
  * Infrastructure and packaging updates.
  * Made many improvements, bug fixes, and significant speed-ups
    for the adaptive resampling algorithm, reproject_adaptive.
    These bug fixes may cause changes to the reprojected images,
    which are typically negligible.Improvements include the
    addition of a flux-conserving mode, support for a Gaussian
    filter kernel, a menu of boundary-handling modes, and a
    center_jacobian flag to trade speed for accuracy with
    rapidly-varying transformations.
  * Added a roundtrip_coords argument to reproject_adaptive and
    reproject_interp. By default, all coordinate transformations
    are run in both directions to handle some situations where they
    are ambiguous. This can be disabled by setting
    roundtrip_coords=False which may offer a significant speed
    increase.
* Sun Feb  6 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 0.8
- Required by sunpy testing (optional runtime requirement)
